@@ -42,6 +42,12 @@ class Term():
             self.index = self.index-set(operator.index_labels)
         # ------------------- for operator
 
+    def __lsub__(self, other):
+        return self.__sub__(other)
+
+    def __rsub__(self, other):
+        return self.__sub__(other)
+
     def __sub__(self, other):
         return self.__add__(-1*other)
 
